<?php
/*
Addon: TEAMVISION Functions 
*/

/** Get Animations **/
if(!function_exists('headerblocks_animate_class')) {
	function headerblocks_animate_class($addon_animate,$effect,$delay) {
		if($addon_animate == 'on') : 
			wp_enqueue_script( 'appear' );			
			wp_enqueue_script( 'animate' );		
			$animate_class = ' animate-in" data-anim-type="'.$effect.'" data-anim-delay="'.$delay.'"'; 
		else :
			$animate_class = '"';
		endif;		
		return $animate_class;
	}
}

/** Get Category **/
if(!function_exists('headerblocks_get_category')) {
	function headerblocks_get_category($source,$posts_type,$css_link = '',$limit = 1) {
		$separator = ' ';
		$output = '';	
		$count = 1;
		if($source=='wp_posts') {			
			$categories = get_the_category();
			if($categories){
				foreach($categories as $category) {
					$output .= '<a href="'.get_category_link( $category->term_id ).'" title="' . esc_attr( sprintf( __( "View all posts in %s",'elementor-header-blocks' ), $category->name ) ) . '" '.$css_link.'>'.esc_html($category->cat_name).'</a>'.esc_html($separator);
					if($count == $limit) { break; }
					$count++;
				}
			}
		} elseif($source=='post_type') {
			global $post;
			$taxonomy_names = get_object_taxonomies( $posts_type );
			$term_list = wp_get_post_terms($post->ID,$taxonomy_names);
			if($term_list){
				foreach ($term_list as $tax_term) {
					$output .= '<a href="' . esc_attr(get_term_link($tax_term, $posts_type)) . '" title="' . sprintf( __( "View all posts in %s",'elementor-header-blocks' ), $tax_term->name ) . '" '.$css_link.'>' . esc_html($tax_term->name) .'</a>'.esc_html($separator);
				}
			}
		}
		$return = trim($output, $separator);
		return $return;
	}
}

/** Get Author **/
if(!function_exists('headerblocks_get_author')) {
	function headerblocks_get_author($css_link) {
		$return = '<a href="'.get_author_posts_url( get_the_author_meta( 'ID' ) ).'" '.$css_link.'>'.get_the_author_meta( 'display_name' ).'</a>';
		return $return;
	}	
}

/** Get Comments **/
if(!function_exists('headerblocks_get_num_comments')) {	
	function headerblocks_get_num_comments($css_comment,$css_comment_link) {
			$num_comments = get_comments_number();

			if ( $num_comments == 0 ) {
					$comments = esc_html__('No Comments','elementor-header-blocks');
					$return = $comments;
			} elseif ( $num_comments > 1 ) {
					$comments = $num_comments . esc_html__(' Comments','elementor-header-blocks');
					$return = '<a href="' . get_comments_link() .'" '.$css_comment_link.'>'. esc_html($comments).'</a>';
			} else {
					$comments = esc_html__('1 Comment','elementor-header-blocks');
					$return = '<a href="' . get_comments_link() .'" '.$css_comment_link.'>'. esc_html($comments) .'</a>';
			}
			return $return;
	}
}

if(!function_exists('headerblocks_get_only_num_comments')) {
	function headerblocks_get_only_num_comments($css_comment,$css_comment_link) {
			$num_comments = get_comments_number();

			if ( $num_comments == 0 ) {
					$return = '<span '.$css_comment.'>'.esc_html($num_comments).'</span>';
			} elseif ( $num_comments > 1 ) {
					$return = '<a href="' . get_comments_link() .'" '.$css_comment_link.'>'. esc_html($num_comments).'</a>';
			} else {
					$return = '<a href="' . get_comments_link() .'" '.$css_comment_link.'>'. esc_html($num_comments).'</a>';
			}
			return $return;
	}
}

/** Get Thumbnails **/
if(!function_exists('headerblocks_get_thumb')) {
	function headerblocks_get_thumb($thumbs_size = 'headerblocks-normal') {
		global $post;
		$link = get_the_permalink();
		if(has_post_thumbnail()){ 
				$id_post = get_the_id();					
				$single_image = wp_get_attachment_image_src( get_post_thumbnail_id($id_post), $thumbs_size );	
				$return = '<a href="'.$link.'"><img class="headerblocks-thumbs" src="'.$single_image[0].'" alt="'.get_the_title().'"></a>';
			} else {               
				$return = '';                 
		}
		return $return;
	}
}

/** Get Blog Thumbnails **/
if(!function_exists('headerblocks_get_blogs_thumb')) {
	function headerblocks_get_blogs_thumb($columns,$post_id) {
		global $post; 		
		if($columns == '1') :
			$return = headerblocks_get_thumb('headerblocks-blog-large');
		elseif($columns == '2') :
			$return = headerblocks_get_thumb('headerblocks-blog-medium');
		else :
			$return = headerblocks_get_thumb('headerblocks-blog-small');
		endif;	
		return $return;
	}
}	


/** Get Blog Excerpt **/
if(!function_exists('headerblocks_get_blogs_excerpt')) {
	function headerblocks_get_blogs_excerpt($excerpt = 'default',$readmore = 'on',$css_link = '') {
		global $post;
		if($excerpt == 'default') : 
			$return = get_the_excerpt();
		else :
			$return = substr(get_the_excerpt(), 0, $excerpt);
			if($readmore == 'on') :
				$return .= '<a class="article-read-more" href="'. get_permalink($post->ID) . '" '.$css_link.'>'.esc_html__('Read More','elementor-header-blocks').'</a>';
			else :
				$return .= '...';
			endif;
		endif;
		return $return;
	}
}

/** Get News Excerpt **/
if(!function_exists('headerblocks_get_news_excerpt')) {
	function headerblocks_get_news_excerpt($excerpt = 'default',$readmore = 'on',$css_link) {
		global $post;
		if($excerpt == 'default') : 
			$return = get_the_excerpt();
		else :
			$return = substr(get_the_excerpt(), 0, $excerpt);
			if($readmore == 'on') :
				$return .= '<a class="article-read-more" href="'. get_permalink($post->ID) . '" '.$css_link.'><i class="fa fa-angle-double-right"></i></a>';
			else :
				$return .= '...';
			endif;
		endif;
		return $return;
	}
}

/** Get News Excerpt **/
if(!function_exists('headerblocks_get_news_v2_excerpt')) {
	function headerblocks_get_news_v2_excerpt($excerpt = 'default',$readmore = 'on',$css_link) {
		global $post;
		if($excerpt == 'default') : 
			$return = get_the_excerpt();
		else :
			$return = substr(get_the_excerpt(), 0, $excerpt);
			if($readmore == 'on') :
				$return .= '<a class="article-read-more" href="'. get_permalink($post->ID) . '" '.$css_link.'>...</a>';
			else :
				$return .= '...';
			endif;
		endif;
		return $return;
	}
}

/** Check Post Format **/
if(!function_exists('headerblocks_check_post_format')) {
	function headerblocks_check_post_format() {
		global $post;
		$format = get_post_format_string( get_post_format() );
		if($format == 'Video') :
			$return = '<span class="headerblocks-format-type fa fa-play-circle-o"></span>';
		elseif($format == 'Audio') :
			$return = '<span class="headerblocks-format-type fa fa-headphones"></span>';
		else :
			$return = '';
		endif;
		return $return;
	}
}

/** Post Social Share **/
if(!function_exists('headerblocks_post_social_share')) {
	function headerblocks_post_social_share($css_link = '') {
		
		$return = '<div class="share">
			<div class="icon">	
				<a target="_blank" href="http://www.facebook.com/sharer.php?u='.get_the_permalink().'&amp;t='.get_the_title().'" title="'.esc_html__('Click to share this post on Facebook','elementor-header-blocks').'" '.$css_link.'><i class="icon-facebook2"></i></a>
				<a target="_blank" href="http://twitter.com/home?status='.get_the_permalink().'" title="'.esc_html__('Click to share this post on Twitter','elementor-header-blocks').'"><i class="icon-twitter" '.$css_link.'></i></a>
				<a target="_blank" href="https://plus.google.com/share?url='.get_the_permalink().'" title="'.esc_html__('Click to share this post on Google+','elementor-header-blocks').'"><i class="icon-googleplus2" '.$css_link.'></i></a>
				<a target="_blank" href="http://www.linkedin.com/shareArticle?mini=true&amp;url='.get_the_permalink().'" title="'.esc_html__('Click to share this post on Linkedin','elementor-header-blocks').'"><i class="icon-linkedin" '.$css_link.'></i></a>
				<a href="#" class="share-icon icon-rocket"></a>
			</div>	
		</div>';
		
		return $return;
	}
}
/** Get Numeric Pagination **/
if(!function_exists('headerblocks_posts_numeric_pagination')) {
	function headerblocks_posts_numeric_pagination($pages = '', $range = 2,$loop,$paged,$css_current_pag_num,$css_link) {  
		 $showitems = ($range * 2)+1;  

		 if(empty($paged)) $paged = 1;

		 if($pages == '')
		 {
			 $pages = $loop->max_num_pages;
			 if(!$pages)
			 {
				 $pages = 1;
			 }
		 }   
		
		 $return = '';
		
		 if(1 != $pages) {		 	
			 $return .= "<div class='fnwp-numeric-pagination'>";
			 if($paged > 2 && $paged > $range+1 && $showitems < $pages) $return .=  "<a href='".get_pagenum_link(1)."' class=\"fnwp-pagination-numeric-arrow\" ".$css_link."><i class=\"fa fa-angle-double-left fnwp-icon-double-left\"></i></a>";
			 if($paged > 1 && $showitems < $pages) $return .=  "<a href='".get_pagenum_link($paged - 1)."' class=\"fnwp-pagination-numeric-arrow\" ".$css_link."><i class=\"fa fa-angle-left fnwp-icon-left\"></i></a>";

			 for ($i=1; $i <= $pages; $i++)
			 {
				 if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
				 {
					 $return .=  ($paged == $i)? "<span class='current' ".$css_current_pag_num.">".$i."</span>":"<a href='".get_pagenum_link($i)."' class='inactive' ".$css_link.">".$i."</a>";
				 }
			 }

			 if ($paged < $pages && $showitems < $pages) $return .= "<a href='".get_pagenum_link($paged + 1)."' class=\"fnwp-pagination-numeric-arrow\" ".$css_link."><i class=\"fa fa-angle-right fnwp-icon-right\"></i></a>";
			 if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) $return .=  "<a href='".get_pagenum_link($pages)."' class=\"fnwp-pagination-numeric-arrow\" ".$css_link."><i class=\"fa fa-angle-double-right fnwp-icon-double-right\"></i></a>";
			 $return .=  "</div>\n";
		 }
		 
		 return $return;
	}
}

/* Gallery Pagination */
function headerblocks_get_gallery_pagination($num_page_for_pagination,$pagination) {
	$output = '<ul class="headerblocks_gallery_pagination">';
	for($i=1; $i <= $num_page_for_pagination; $i++) {
		
		if($i == $pagination) {
			$output .= '<li class="mg_current">'.esc_html($i).'</li>'; // CURRENT PAGE
		} else {
			$output .= '<li><a href="'.get_post_permalink().'&mg_page='.$i.'">'.esc_html($i).'</a></li>'; // OTHER PAGE
		}
	}
	$output .= '</ul>';
	return $output;
}

/* Var Gallery Pagination */
function headerblocks_add_query_vars_headerblocks_gallery_pagination( $vars ){
  $vars[] = "mg_page";
  return $vars;
}
add_filter( 'query_vars', 'headerblocks_add_query_vars_headerblocks_gallery_pagination' );

/* Gallery Share Button */
function headerblocks_share_button($id,$image_lightbox,$text_caption) {
	$return = '';
	$return .= '<a href="" class="fa fa-share-alt"></a>';
	$return .= '<div class="headerblocks-gallery-social-share-container">';
		$return .= '<div class="headerblocks-gallery-social-share-container-content">';
			$return .= '<a target="_blank" href="http://www.facebook.com/sharer.php?caption='.$text_caption.'&description='.$text_caption.'&u='.$image_lightbox.'&picture='.$image_lightbox.'"><i class="fa fa-facebook"></i></a>';
		$return .= '</div>';
	$return .= '</div>';
	return $return;
	
}

if(!function_exists('headerblocks_query')) {
	function headerblocks_query( $source,
						$posts_source, 
						$posts_type, 
						$categories,
						$categories_post_type,
						$order, 
						$orderby, 
						$pagination, 
						$pagination_type,
						$num_posts, 
						$num_posts_page) {
								  
						if($orderby == 'views') { 
								$orderby = 'meta_value_num'; 
								$view_order = 'views';
						} else { $view_order = ''; }	
										
						if($source == 'post_type') {
							$posts_source = 'all_posts';
						}
						
						if($posts_source == 'all_posts') {
						
							$query = 'post_type=Post&post_status=publish&ignore_sticky_posts=1&orderby='.$orderby.'&order='.$order.'';						
							
							// CUSTOM POST TYPE
							if($source == 'post_type') {
								$query .= '&post_type='.$posts_type.'';
							}

							if($view_order == 'views') { 
								$query .= '&meta_key=wpb_post_views_count';
							}
							
							// CATEGORIES POST TYPE
							if($categories_post_type != '' && !empty($categories_post_type) && $source == 'post_type') {
								$taxonomy_names = get_object_taxonomies( $posts_type );
								$query .= '&'.$taxonomy_names[0].'='.$categories_post_type.'';	
							}

							// CATEGORIES POSTS
							if($categories != '' && $categories != 'all' && !empty($categories) && $source == 'wp_posts') {
								$query .= '&category_name='.$categories.'';	
							}
								
							if($pagination == 'yes' || $pagination == 'load-more') {
								$query .= '&posts_per_page='.$num_posts_page.'';	
							} else {
								if($num_posts == '') { $num_posts = '-1'; }
								$query .= '&posts_per_page='.$num_posts.'';
							}
						
							// PAGINATION		
							if($pagination == 'yes' || $pagination == 'load-more') {
								if ( get_query_var('paged') ) {
									$paged = get_query_var('paged');
								
								} elseif ( get_query_var('page') ) {			
									$paged = get_query_var('page');			
								} else {			
									$paged = 1;			
								}			
								$query .= '&paged='.$paged.'';
							}
							// #PAGINATION	
						
						} else { // IF STICKY
							

							if($pagination == 'yes' || $pagination == 'load-more') {
								$num_posts = $num_posts_page;	
							} else {
								if($num_posts == '') { $num_posts = '-1'; }
								$num_posts = $num_posts;
							}

							// PAGINATION		
							
							if ( get_query_var('paged') ) {
								$paged = get_query_var('paged');							
							} elseif ( get_query_var('page') ) {			
								$paged = get_query_var('page');			
							} else {			
								$paged = 1;			
							}			
							
							// #PAGINATION	
												
							/* STICKY POST DA FARE ARRAY PER SCRITTURA IN ARRAY */
						
							$sticky = get_option( 'sticky_posts' );
							$sticky = array_slice( $sticky, 0, 5 );
							if($view_order == 'views') { 
								$query = array(
									'post_type' => 'post',
									'post_status' => 'publish',
									'orderby' 	=> $orderby,
									'order' => $order,
									'category_name' => $categories,
									'posts_per_page' => $num_posts,
									'meta_key' => 'wpb_post_views_count',
									'paged' => $paged, 
									'post__in'  => $sticky,
									'ignore_sticky_posts' => 1
								);
							} else {
								$query = array(
									'post_type' => 'post',
									'post_status' => 'publish',
									'orderby' 	=> $orderby,
									'order' => $order,
									'category_name' => $categories,
									'posts_per_page' => $num_posts,
									'paged' => $paged, 
									'post__in'  => $sticky,
									'ignore_sticky_posts' => 1
								);
							}						
							
						} // #all_posts
						
						return $query;	
	}
}

function headerblocks_header_custom_style($instance,$type,$layout,$maincolor,$secondcolor,$thirdcolor) {
	
	$return = '<style type="text/css">';
	
	if($type == 'type1') {
		
		if($layout == 'layout1') {
		
			$return .= '.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .share a,
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .share-icon:hover,
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .title-info-post a, 
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin.first .title-info-post a, 
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .title-info-post a,
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .title-info-post span, 
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin.first .title-info-post span, 
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .title-info-post span,
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post i, 
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin i,
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .separator {
							color:'.$secondcolor.';
						}
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .category a {
							border-left:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .category a:hover,
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .info-post, 
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .info-post {
							background:'.$maincolor.';						
						}
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .title-info-post a:hover, 
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .title-info-post a:hover,
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .icon-calendar {
							color:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .share a:hover,
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .info-post a:hover, 
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .info-post a:hover,  
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .share .icon a:hover,
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .info-post span:hover,
						.headerblocks.wpmp_post_display1.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .info-post span:hover {
							color:'.$thirdcolor.';
						}';
		
		} else {
			
			$return .= '.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .separator {
							color:'.$secondcolor.';
						}
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .category a {
							border-left:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .category a:hover,
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .info-post, 
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .info-post {
							background:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .icon-calendar,
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .title-info-post a:hover, 
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .title-info-post a:hover {
							color:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .share a:hover,
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .info-post a:hover, 
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .info-post a:hover,  
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .share .icon a:hover,
						.headerblocks.wpmp_post_display1_bis.wpmepack-header-'.$instance.' .category a:hover  {
							color:'.$thirdcolor.';
						}';
						
		}	
		
	}
	
	if($type == 'type2') {
		
		if($layout == 'layout1') {
		
			$return .= '.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_third.ad_margin .box-post,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .ad_one_one .category a,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .ad_one_third .category a,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .category a:hover,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .share a,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .share-icon:hover,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post a,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post i,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .separator,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post span {
							color:'.$secondcolor.';
						}
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_third.ad_margin {
							background:'.$secondcolor.';
						}
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .ad_one_one .category a {
							border-left:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .ad_one_third .category a {
							border-right:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .category a:hover,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .info-post {
							background:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post a:hover,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_third.ad_margin .box-post:hover .title-info-post .title-post a,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_third.ad_margin .data:hover,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .icon-calendar {
							color:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .share a:hover,
						.headerblocks.wpmp_post_display2.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .info-post a:hover {
							color:'.$thirdcolor.';
						}
			';
		
		} else {
			
			$return .= '.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .ad_one_one .category a {
							border-left:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .ad_one_third .category a {
							border-top: 2px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .category a:hover,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .info-post {
							background:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post a:hover,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post a:hover,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_third.ad_margin .box-post:hover .title-info-post .title-post a,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_third.ad_margin .data:hover,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .icon-calendar {
							color:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_third.ad_margin .box-post,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_third.ad_margin.second,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_third.ad_margin.third {
							background:'.$secondcolor.';
						}
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .ad_one_one .category a,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .ad_one_third .category a,					
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .share a,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .share-icon:hover,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post a,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post span,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .info-post a,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .info-post span,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post i,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .separator {
							color:'.$secondcolor.';
						}				
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .share a:hover,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .info-post a:hover,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .category a:hover,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_third.ad_margin .data,
						.headerblocks.wpmp_post_display2_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_third.ad_margin .title-info-post h4 a {
							color:'.$thirdcolor.';
						}';
			
		}
		
	}	
	
	if($type == 'type3') {
		
		if($layout == 'layout1') {
		
			$return .= '.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .category a {
							border-left:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .category a:hover,
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .info-post, 
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .info-post {
							background:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .title-info-post a:hover, 
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_fifth.ad_margin .title-info-post a:hover, 
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .title-info-post a:hover,
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .icon-calendar {
							color:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .category a,
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .share a,
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .share-icon:hover,
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .title-info-post a, 
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_fifth.ad_margin .title-info-post a, 
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .title-info-post a, 
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item .title-info-post span,
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post i, 
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin i, 
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .info-post,
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .separator {
							color:'.$secondcolor.';
						}
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .share a:hover,
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .info-post a:hover, 
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .info-post a:hover,  
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .share .icon a:hover,
						.headerblocks.wpmp_post_display3.wpmepack-header-'.$instance.' .category a:hover {
							color:'.$thirdcolor.';
						}						
						';
		
		} else {
			
			$return .= '.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .category a,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .ad_one_fifth .share,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .ad_one_fifth .share a,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .share a,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .share-icon:hover,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .title-info-post a, 
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_fifth.ad_margin .title-info-post a, 
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .title-info-post a,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .title-info-post span,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .title-info-post span,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post i, 
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin i,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .info-post a, 
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth .info-post a,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .info-post span,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth .info-post span,						
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_fifth.big-post .title-info-post span,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_fifth.ad_margin .title-info-post span,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .separator,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .data {
							color:'.$secondcolor.';
						}
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .category a {
							border-left:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .category a:hover,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .ad_one_fifth .share,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .info-post, 
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .info-post {
							background:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .title-info-post a:hover, 
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_fifth.ad_margin .title-info-post a:hover, 
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .title-info-post a:hover,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .icon-calendar {
							color:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .share a:hover,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_three_fifth.big-post .info-post a:hover, 
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_two_fifth.ad_margin .info-post a:hover,  
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .share .icon a:hover,
						.headerblocks.wpmp_post_display3_bis.wpmepack-header-'.$instance.' .category a:hover {
							color:'.$thirdcolor.';
						}';
							
		}
		
	}
	
	if($type == 'type4') {
		
		if($layout == 'layout1') {
		
			$return .= '.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.'  .ad_one_one .category a {
							border-left:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.'  .ad_one_third .category a {
							border-right:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.'  .category a:hover,
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.'  .share {
							background:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post a:hover,
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .icon-calendar,
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .owl-controls .owl-nav [class*="owl-"]:hover {
							color:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .ad_one_one .category a,
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .ad_one_third .category a,
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .share a,
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .share-icon:hover,
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post a,
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post i,
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post span,
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post .category a:hover	{
							color:'.$secondcolor.';
						}
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .share a:hover,
						.headerblocks.wpmp_post_display4.wpmepack-header-'.$instance.' .category a:hover {
							color:'.$thirdcolor.'!important;
						}					
						';
						
		} else {
			
			$return .= '.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.'  .ad_one_one .category a {
							border-left:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.'  .ad_one_third .category a {
							border-right:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.'  .category a:hover,
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.'  .share {
							background:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post a:hover,
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .icon-calendar,
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .owl-controls .owl-nav [class*="owl-"]:hover {
							color:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .ad_one_one .category a,
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .ad_one_third .category a,
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .share a,
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .share-icon:hover,
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post a,
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post i,
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post .title-info-post span	{
							color:'.$secondcolor.';
						}
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .share a:hover,
						.headerblocks.wpmp_post_display4_bis.wpmepack-header-'.$instance.' .category a:hover {
							color:'.$thirdcolor.'!important;
						}					
						';
			
		}
	}
	
	if($type == 'type5') {
		
		if($layout == 'layout1') {
		
			$return .= '.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .ad_one_one .category a {
							border-left:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .ad_one_third .category a {
							border-right:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .category a:hover,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .share .info-comments {
							background:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .info-post i,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .title-info-post.ad_one_half a:hover,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .icon-calendar,
						.wpmp_post_display5.wpmepack-header-'.$instance.' .mini-post .title-post a:hover,
						.wpmp_post_display5.wpmepack-header-'.$instance.' .mini-post .info-post a:hover  {
							color:'.$maincolor.';
						}';
	
			$return .= '.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .ad_one_one .category a,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .ad_one_third .category a,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .category a:hover,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .title-info-post.ad_one_half p,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .info-post a,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .title-info-post.ad_one_half span,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .separator,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .view,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .share a,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .share-icon:hover,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .title-info-post.ad_one_half a,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .title-info-post.ad_one_half span,
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post i,
						.wpmp_post_display5.wpmepack-header-'.$instance.' .mini-post .title-post a {
							color:'.$secondcolor.';
						}';
			
			$return .= '.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.',
						.headerblocks.wpmp_post_display5.wpmepack-header-'.$instance.' .ad_one_third .category a {
							background:'.$thirdcolor.';
						}';
		
		} else {
			
			$return .= '.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .ad_one_one .category a {
							border-left:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .ad_one_one .category a {
							border-right:5px solid '.$maincolor.';
						}
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .category a:hover,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .share .info-comments {
							background:'.$maincolor.';
						}
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .info-post i,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .title-info-post.ad_one_half a:hover,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .icon-calendar,
						.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .mini-post .title-post a:hover,
						.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .mini-post .info-post a:hover  {
							color:'.$maincolor.';
						}';
	
			$return .= '.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .ad_one_one .category a,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .ad_one_third .category a,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .category a:hover,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .share,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .title-info-post.ad_one_half p,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .info-post a,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .title-info-post.ad_one_half span,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .separator,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .view,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .share a,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .share-icon:hover,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .title-info-post.ad_one_half a,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .title-info-post.ad_one_half span,
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .headerblocks-item.ad_one_one.ad_last.big-post i,
						.wpmp_post_display5.wpmepack-header-'.$instance.' .mini-post .title-post a {
							color:'.$secondcolor.';
						}';
			
			$return .= '.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.',
						.headerblocks.wpmp_post_display5_bis.wpmepack-header-'.$instance.' .ad_one_third .category a {
							background:'.$thirdcolor.';
						}';
						
		}
		
		
	}
	
	
	$return .= '</style>';
	
	
	return $return;
}

/**************************************************************************/
/************************** FUNCTION VIEW *********************************/
/**************************************************************************/

function headerblocks_get_post_views($postID){
    $count_key = 'wpb_post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
		$view = __('Views','headerblocks');
        return "0";
    }
	$count_final = $count; 
    return $count_final;
}

function headerblocks_set_post_views() {
	if ( is_single() ) {
	global $post;
	$postID = $post->ID;	
    $count_key = 'wpb_post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
	}
}
add_filter( 'wp_footer', 'headerblocks_set_post_views', 200000 );

function headerblocks_thumbs_url($id_post) {
	global $post;
	if(has_post_thumbnail()){  
			$id_post = get_the_id();					
			$single_image = wp_get_attachment_image_src( get_post_thumbnail_id($id_post), 'wpmegaposts-header' );	 					 
		} else {               
             $single_image[0] = WPMP_VC_URL .'assets/img/no-img.jpg';                
    }	
	$return = $single_image[0];
	return $return;
}